.. image:: .github/banner.png
  :class: with-border
  :width: 1280

========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs:
      - |docs|
    * - tests:
      - | |travis| |appveyor| |requires| |codecov|
    * - package:
      - | |version| |commits-since|
    * - infra:
      - | |github-actions|

.. |docs| image:: https://readthedocs.org/projects/sylenium/badge/?style=flat
    :target: https://sylenium.readthedocs.io/en/latest/
    :alt: Documentation Status

.. |travis| image:: https://api.travis-ci.org/symonk/sylenium.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/symonk/sylenium

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/github/symonk/sylenium?branch=master&svg=true
    :alt: AppVeyor Build Status
    :target: https://ci.appveyor.com/project/symonk/sylenium

.. |requires| image:: https://requires.io/github/symonk/sylenium/requirements.svg?branch=master
    :alt: Requirements Status
    :target: https://requires.io/github/symonk/sylenium/requirements/?branch=master

.. |codecov| image:: https://codecov.io/gh/symonk/sylenium/branch/master/graphs/badge.svg?branch=master
    :alt: Coverage Status
    :target: https://codecov.io/github/symonk/sylenium

.. |version| image:: https://img.shields.io/pypi/v/sylenium.svg
    :alt: PyPI Package latest release
    :target: https://pypi.org/project/sylenium

.. |wheel| image:: https://img.shields.io/pypi/wheel/sylenium.svg
    :alt: PyPI Wheel
    :target: https://pypi.org/project/sylenium

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/sylenium.svg
    :alt: Supported versions
    :target: https://pypi.org/project/sylenium

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/sylenium.svg
    :alt: Supported implementations
    :target: https://pypi.org/project/sylenium

.. |commits-since| image:: https://img.shields.io/github/commits-since/symonk/sylenium/v0.1.1.svg
    :alt: Commits since latest release
    :target: https://github.com/symonk/sylenium/compare/v0.1.1...master

.. |github-actions| image:: https://github.com/symonk/sylenium/workflows/Release%20sylenium/badge.svg
    :alt: Automated Releasing
    :target: https://github.com/symonk/sylenium/workflows/Release%20sylenium/badge.svg


.. end-badges

========
What is Sylenium?
========

Selenium wrapper for automating web applications end to end. Sylenium helps you get off the ground running and has a
core focus on improving stability of selenium when used for test writing.  With Selenium 4 upcoming, Sylenium aims for
its first release in Q1 2021.  Sylenium contains test runner framework plugin(s) and is test runner agnostic.


=============
Documentation
=============

https://sylenium.readthedocs.io/
